@@ -18,10 +18,10 @@ class Analizer(threading.Thread):
         super().__init__()
 
     def run(self):
-        with open("./../top-pypi-packages-30-days.json", "r") as file:
+        with open("top-pypi-packages-30-days.json", "r") as file:
             data = json.load(file)
             for p in data["rows"]:
                 obj = Package(p["project"], p["download_count"], Algos.generate_typo(p["project"]))
                 self.package_list.append(obj)
 
-    print(Algos.hamming_distance("abc", "yxz"))
+    #print(Algos.hamming_distance("abc", "yxz"))
